@@ -4,33 +4,33 @@ data_location = os.path.join(__dir__, "system_verilog")
 src = "https://github.com/openhwgroup/cv32e40s"
 
 # Module version
-version_str = "0.4.0.post262"
-version_tuple = (0, 4, 0, 262)
+version_str = "0.5.0.post299"
+version_tuple = (0, 5, 0, 299)
 try:
     from packaging.version import Version as V
-    pversion = V("0.4.0.post262")
+    pversion = V("0.5.0.post299")
 except ImportError:
     pass
 
 # Data version info
-data_version_str = "0.4.0.post120"
-data_version_tuple = (0, 4, 0, 120)
+data_version_str = "0.5.0.post157"
+data_version_tuple = (0, 5, 0, 157)
 try:
     from packaging.version import Version as V
-    pdata_version = V("0.4.0.post120")
+    pdata_version = V("0.5.0.post157")
 except ImportError:
     pass
-data_git_hash = "d11f4a036f2e8ed322188b3460ea27f2f228b585"
-data_git_describe = "0.4.0-120-gd11f4a03"
+data_git_hash = "3462ed208034635ac81cfffe6dd616c3fc4c196a"
+data_git_describe = "0.5.0-157-g3462ed20"
 data_git_msg = """\
-commit d11f4a036f2e8ed322188b3460ea27f2f228b585
-Merge: 26b419dc adc412cf
+commit 3462ed208034635ac81cfffe6dd616c3fc4c196a
+Merge: 0ac403b7 5a41c42b
 Author: Arjan Bink <40633348+Silabs-ArjanB@users.noreply.github.com>
-Date:   Fri Jul 15 12:18:13 2022 +0200
+Date:   Wed Oct 12 09:52:11 2022 +0200
 
-    Merge pull request #254 from Silabs-ArjanB/ArjanB_244
+    Merge pull request #324 from silabs-oysteink/silabs-oysteink_merge-w41
     
-    Fix for PMPADDR
+    Merge from CV32E40X
 
 """
 
